// Copyright 2014-2017 Insight Software Consortium.
// Distributed under the Boost Software License, Version 1.0.
// Copyright 2004-2009 Roman Yakovenko.
// See http://www.boost.org/LICENSE_1_0.txt

// A function pointer
void (*myFuncPointer)(int, double);
